;#############################################################################
;
; Copyright (C) 2008-2013, Michele Cappellari
; E-mail: michele.cappellari_at_physics.ox.ac.uk
;
; Updated versions of the software are available from my web page
; http://purl.org/cappellari/software
;
; If you have found this software useful for your research,
; I would appreciate an acknowledgment and a link to the website.
;
; This software is provided as is without any warranty whatsoever.
; Permission to use, for non-commercial purposes is granted.
; Permission to modify for personal or internal use is granted,
; provided this copyright and disclaimer are included unchanged
; at the beginning of the file. All other rights are reserved.
;
;#############################################################################
function cap_ibetam, a1, b, x
compile_opt idl2
on_error, 2
;
; Incomplete beta function defined in the same 
; way as the Mathematica function Beta[x,a,b].
; Beta[x,a,b] = Integral[t^(a-1) * (1-t)^(b-1), {t,0,x}]
; This routine requires x < 1 && b > 0.
; It was tested against Mathematica.
;
; V1.0: Michele Cappellari, Oxford, 01/APR/2008
; V2.0: Use Hypergeometric function for a < 0 || b < 0.
;    From equation (6.6.8) of Abramoviz & Stegun (1965)
;    See the book here http://www.nr.com/aands/ 
;    MC, Oxford, 04/APR/2008
; V3.0: Use recurrence relation of equation (26.5.16) 
;    from Abramoviz & Stegun (1965) for a < 0 && b > 0.
;    Removed case b < 0 which is not required for JAM.
;    See the book here http://www.nr.com/aands/
;    After suggestion by Gary Mamon. MC, Oxford, 16/APR/2009
; V3.01: Renamed CAP_IBETAM to avoid potential naming conflicts.
;    MC, Paranal, 8 November 2013

a = a1 + 3d-7 ; Perturb to avoid singularities in gamma and ibeta
if b ge 0 then $
    if a ge 0 then $
        ib = ibeta(a,b,x)*beta(a,b) $
    else begin        
        p = ceil(abs(a))
        sum = 0d ; Summation is vectorized over x
        for j=0,p-1 do sum += gamma(a+b+j)/gamma(a+j+1d)*x^(a+j)
        ib = (sum*(1d - x)^b/gamma(b) + ibeta(a+p,b,x)) * beta(a,b)
    endelse else message, 'b < 0 not implemented'     
     
return, ib 
end
;----------------------------------------------------------------------