;----------------------------------------------------------------------------
pro cap_meshgrid, x, y, xx, yy
;
; Emulates MATLAB function MESHGRID.
; 
;   CAP_MESHGRID, X, Y, XX, YY 
; 
; replicates the grid vectors X and Y to produce a full grid. This grid 
; is represented by the output coordinate arrays XX and YY. The output 
; coordinate arrays XX and YY contain copies of the grid vectors X and Y 
; respectively. The sizes of the output arrays are determined by the 
; length of the grid vectors. For grid vectors X and Y of length M and N 
; respectively, XX and YY will have dimension XX[M,N] and YY[M,N].
; 
; V1.0: By Michele Cappellari, Leiden, 14 February 2004
; V2.0: Uses REBIN instead of # for increased speed and 
;   smaller memory footprint. Updated documentation. 
;   MC, Oxford, 3 April 2012
; V2.01: Renamed CAP_MESHGRID to avoid potential naming conflicts.
;   MC, Paranal, 8 November 2013
;     
;
COMPILE_OPT IDL2
on_error, 2

nx = n_elements(x)
ny = n_elements(y)
xx = rebin(x, nx, ny)
yy = rebin(transpose(y), nx, ny)

END
;----------------------------------------------------------------------------
